package com.liquidnet.service.galaxy.dto;

import com.liquidnet.commons.lang.util.JsonUtils;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.io.Serializable;

/**
 * @author AnJiabin <anjiabin@zhengzai.tv>
 * @version V1.0
 * @Description: NFT购买(涉及NFT发行、NFT购买)
 * @class: GalaxyNftBuyReqDto
 * @Package com.liquidnet.service.galaxy.dto
 * @Copyright: LightNet @ Copyright (c) 2021
 * @date 2022/3/14 18:13
 */
@ApiModel(value = "GalaxyNftBuyReqDto", description = "NFT购买")
@Data
public class GalaxyNftBuyReqDto implements Serializable,Cloneable  {
    /**
     * 以下为发行参数***********************************
     */
    @ApiModelProperty(position = 1, required = true, value = "用户ID[30]")
    @NotBlank(message = "用户ID不能为空！")
    @Size(min = 1, max = 30, message = "用户ID限制2-30位且不能包含特殊字符")
    private String userId;
    /**
     * skuId
     */
    private String skuId;
    /**
     * nft名字(sku名称)，中英文数字均可，不超过256个字符
     */
    private String name;
    /**
     * nftUrl，不超过1024个字符
     */
    private String url;
    /**
     * 预览图url，不超过1024个字符。(至信链浏览器展示预览图尺寸为290*290，请上传比例为1:1的图片)
     */
    private String displayUrl;
    /**
     * nft简介，500个字符以内
     */
    private String desc;
    /**
     * 标签，【文创】，游戏，动漫，30个字符以内
     * 非必填
     */
    private String flag;
    /**
     * 发行量，如果没有系列，就只能为1，如果有系列从1开始，比如如有100个，系列id范围则为[1-100],单次发行个数不超过1000，
     * 同系列下同介质个数总共不能超过3000
     */
    private String publishCount;
    /**
     * 可售状态下有意义，表示售卖多少积分
     */
    private String sellCount;

    @Override
    public String toString(){
        return JsonUtils.toJson(this);
    }

    private static final GalaxyNftBuyReqDto obj = new GalaxyNftBuyReqDto();

    public static GalaxyNftBuyReqDto getNew() {
        try {
            return (GalaxyNftBuyReqDto) obj.clone();
        } catch (CloneNotSupportedException e) {
            return new GalaxyNftBuyReqDto();
        }
    }
}
